Description: Fix various typos
Author: Benjamin Drung <benjamin.drung@profitbricks.com>

--- a/man/man8/bak2db.pl.8
+++ b/man/man8/bak2db.pl.8
@@ -58,7 +58,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/cleanallruv.pl.8
+++ b/man/man8/cleanallruv.pl.8
@@ -61,7 +61,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/db2bak.pl.8
+++ b/man/man8/db2bak.pl.8
@@ -56,7 +56,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/db2index.pl.8
+++ b/man/man8/db2index.pl.8
@@ -59,7 +59,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/db2ldif.pl.8
+++ b/man/man8/db2ldif.pl.8
@@ -100,7 +100,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/fixup-linkedattrs.pl.8
+++ b/man/man8/fixup-linkedattrs.pl.8
@@ -52,7 +52,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/fixup-memberof.pl.8
+++ b/man/man8/fixup-memberof.pl.8
@@ -56,7 +56,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/ldif2db.8
+++ b/man/man8/ldif2db.8
@@ -63,7 +63,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/ldif2db.pl.8
+++ b/man/man8/ldif2db.pl.8
@@ -78,7 +78,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/ns-newpwpolicy.pl.8
+++ b/man/man8/ns-newpwpolicy.pl.8
@@ -61,7 +61,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .SH EXAMPLE
 .TP
 ns-newpwpolicy.pl -Z instance3 -D 'cn=directory manager' -w password -P STARTTLS -U 'uid=user,ou=people,dc=example,dc=com' 
--- a/man/man8/schema-reload.pl.8
+++ b/man/man8/schema-reload.pl.8
@@ -52,7 +52,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/syntax-validate.pl.8
+++ b/man/man8/syntax-validate.pl.8
@@ -55,7 +55,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/man/man8/usn-tombstone-cleanup.pl.8
+++ b/man/man8/usn-tombstone-cleanup.pl.8
@@ -58,7 +58,7 @@
 .TP
 .B \fB\-v\fR 
 .br
-Display verbose ouput
+Display verbose output
 .TP
 .B \fB\-h\fR 
 .br
--- a/ldap/servers/slapd/tools/ldclt/data.c
+++ b/ldap/servers/slapd/tools/ldclt/data.c
@@ -51,7 +51,7 @@
 	DESCRIPTION :	
 			This file implements the management of the data that 
 			are manipulated by ldclt.
-			It is targetted to contain all the functions needed for 
+			It is targeted to contain all the functions needed for 
 			the images, etc...
 	LOCAL :		None.
 	HISTORY :
--- a/ldap/servers/slapd/tools/ldclt/ldapfct.c
+++ b/ldap/servers/slapd/tools/ldclt/ldapfct.c
@@ -278,7 +278,7 @@
 
 /* ****************************************************************************
 	FUNCTION :	my_ldap_err2string
-	PURPOSE :	This function is targetted to encapsulate the standard
+	PURPOSE :	This function is targeted to encapsulate the standard
 			function ldap_err2string(), that sometimes returns
 			a NULL pointer and thus crashes the appicaliton :-(
 	INPUT :		err	= error to decode
--- a/ldap/servers/slapd/tools/ldclt/ldclt.c
+++ b/ldap/servers/slapd/tools/ldclt/ldclt.c
@@ -50,10 +50,10 @@
 	DATE :		03 December 1998
 	DESCRIPTION :	
 			This file is the main file of the ldclt tool. This tool 
-			is targetted to be a multi-threaded ldap client, 
+			is targeted to be a multi-threaded ldap client, 
 			specially designed to ensure good reliability of both 
 			the basic ldap server purpose, and the replication 
-			processes. It is *not* targetted against the 
+			processes. It is *not* targeted against the 
 			functionnality aspect of the product, but rather on the 
 			stress and long-term operation.
  	LOCAL :		None.
@@ -672,7 +672,7 @@
 					/* New function */	/*JLS 17-11-00*/
 /* ****************************************************************************
 	FUNCTION :	shutdownThreads
-	PURPOSE :	This function is targetted to shutdown the threads.
+	PURPOSE :	This function is targeted to shutdown the threads.
 	INPUT :		None.
 	OUTPUT :	None.
 	RETURN :	-1 if error, 0 else.
@@ -1750,7 +1750,7 @@
 
 /* ****************************************************************************
 	FUNCTION :	printModeValues
-	PURPOSE :	This function is targetted to print the bits mask of
+	PURPOSE :	This function is targeted to print the bits mask of
 			the mode field.
 	INPUT :		None.
 	OUTPUT :	None.
--- a/ldap/servers/slapd/tools/ldclt/ldclt.h
+++ b/ldap/servers/slapd/tools/ldclt/ldclt.h
@@ -612,7 +612,7 @@
  * This structure is aimed to ease the managing of asynchronous
  * operations, keeping in memory the msgid returned by the library and
  * a free string meaning something for the user.
- * It is targetted that this string is something like a DN, and is
+ * It is targeted that this string is something like a DN, and is
  * locally managed by the list functions.
  */
 typedef struct msgid_cell {
@@ -625,7 +625,7 @@
 
 /*
  * This structure contain the context associated with each thread.
- * It is targetted to be initiated by the main thread, and maintained
+ * It is targeted to be initiated by the main thread, and maintained
  * by each thread.
  */
 typedef struct thread_context {
--- a/ldap/servers/slapd/tools/ldclt/ldclt.man
+++ b/ldap/servers/slapd/tools/ldclt/ldclt.man
@@ -21,7 +21,7 @@
         SUNQAldap
 
 DESCRIPTION
-        ldclt is a multi-threaded test tool targetted to stress a
+        ldclt is a multi-threaded test tool targeted to stress a
         ldap server with multiple simultaneous requests.
 
         The  tool  automatically set its ulimit parameters to fit
--- a/ldap/servers/slapd/tools/ldclt/ldclt.use
+++ b/ldap/servers/slapd/tools/ldclt/ldclt.use
@@ -9,7 +9,7 @@
 	     [-S <slave>] [-P<master port>]
 	     [-W <waitsec>] [-Z <certfile>]
 
-	This tool is a ldap client targetted to validate the reliability of
+	This tool is a ldap client targeted to validate the reliability of
 	the product under test under hard use.
 
 	The valid options are:
--- a/ldap/servers/slapd/tools/ldclt/opCheck.c
+++ b/ldap/servers/slapd/tools/ldclt/opCheck.c
@@ -240,7 +240,7 @@
 
 /* ****************************************************************************
 	FUNCTION :	freeAttributesArray
-	PURPOSE :	This function is targetted to free an array of
+	PURPOSE :	This function is targeted to free an array of
 			struct attribute. It does not free the array itself,
 			but only the types and values memorized in it.
 	INPUT :		attribs	= array to free.
--- a/ldap/servers/slapd/tools/ldclt/workarounds.c
+++ b/ldap/servers/slapd/tools/ldclt/workarounds.c
@@ -49,7 +49,7 @@
         VERSION :       1.0
         DATE :		15 December 1998
         DESCRIPTION :	
-			This file contains special work-arounds targetted to 
+			This file contains special work-arounds targeted to 
 			fix, or work-around, the various bugs that may appear 
 			in Solaris 2.7 libldap.
  	LOCAL :		None.
--- a/ldap/servers/plugins/acl/acllist.c
+++ b/ldap/servers/plugins/acl/acllist.c
@@ -140,7 +140,7 @@
 		
 		if ( (be = slapi_be_select_by_instance_name( be_name )) == NULL) {
 			slapi_log_error ( SLAPI_LOG_ACL, plugin_name, 
-			"Failed to retreive backend--NOT activating it's acis\n");
+			"Failed to retrieve backend--NOT activating it's acis\n");
 			return;
 		}
 
@@ -150,7 +150,7 @@
 
 		if ( (sdn = slapi_be_getsuffix( be, 0)) == NULL ) {
 			slapi_log_error ( SLAPI_LOG_ACL, plugin_name, 
-			"Failed to retreive backend--NOT activating it's acis\n");
+			"Failed to retrieve backend--NOT activating it's acis\n");
 			return;
 		}
 
@@ -167,7 +167,7 @@
 
 		if ( (be = slapi_be_select_by_instance_name( be_name )) == NULL) {
 			slapi_log_error ( SLAPI_LOG_ACL, plugin_name, 
-			"Failed to retreive backend--NOT activating it's acis\n");
+			"Failed to retrieve backend--NOT activating it's acis\n");
 			return;
 		}
 
@@ -177,7 +177,7 @@
 
 		if ( (sdn = slapi_be_getsuffix( be, 0)) == NULL ) {
 			slapi_log_error ( SLAPI_LOG_ACL, plugin_name, 
-			"Failed to retreive backend--NOT activating it's acis\n");
+			"Failed to retrieve backend--NOT activating it's acis\n");
 			return;
 		}
 																	
--- a/ldap/servers/plugins/distrib/Makefile
+++ b/ldap/servers/plugins/distrib/Makefile
@@ -72,7 +72,7 @@
 
 # The sample distribution plugin is not part of DS.
 # So we generate the shared library outside of $(LIBDIR)
-# so that it's not retreived by the packaging makefiles.
+# so that it's not retrieved by the packaging makefiles.
 #LIBDIS =	$(addprefix $(LIBDIR)/, $(DIS_DLL).$(DLL_SUFFIX))
 LIBDIS =	$(addprefix $(OBJDEST)/, $(DIS_DLL).$(DLL_SUFFIX))
 
--- a/ldap/servers/slapd/slapi_counter.c
+++ b/ldap/servers/slapd/slapi_counter.c
@@ -382,7 +382,7 @@
          * replace *ptr with ECX:EBX */
         " lock; cmpxchg8b %0;"
         " jnz retryget;"
-        /* Put retreived value into value */
+        /* Put retrieved value into value */
         " movl %%ebx, %1;"
         " movl %%ecx, 4%1;"
 #ifdef CPU_x86
--- a/ldap/servers/slapd/test-plugins/Makefile.server
+++ b/ldap/servers/slapd/test-plugins/Makefile.server
@@ -72,7 +72,7 @@
 
 # The sample distribution plugin is not part of DS.
 # So we generate the shared library outside of $(LIBDIR)
-# so that it's not retreived by the packaging makefiles.
+# so that it's not retrieved by the packaging makefiles.
 #LIBDIS =	$(addprefix $(LIBDIR)/, $(DIS_DLL).$(DLL_SUFFIX))
 LIBDIS =	$(addprefix $(OBJDEST)/, $(TEST_PLUGIN_DLL).$(DLL_SUFFIX))
 
--- a/ldap/servers/plugins/posix-winsync/posix-winsync-config.c
+++ b/ldap/servers/plugins/posix-winsync/posix-winsync-config.c
@@ -240,7 +240,7 @@
     if (!slapi_entry_attr_find(e, POSIX_WINSYNC_MSSFU_SCHEMA, &testattr) && (NULL != testattr)) {
         mssfuSchema = slapi_entry_attr_get_bool(e, POSIX_WINSYNC_MSSFU_SCHEMA);
         slapi_log_error(SLAPI_LOG_PLUGIN, POSIX_WINSYNC_PLUGIN_NAME,
-                        "_apply_config: Config paramter %s: %d\n", POSIX_WINSYNC_MSSFU_SCHEMA,
+                        "_apply_config: Config parameter %s: %d\n", POSIX_WINSYNC_MSSFU_SCHEMA,
                         mssfuSchema);
     }
 
@@ -248,7 +248,7 @@
     if (!slapi_entry_attr_find(e, POSIX_WINSYNC_MAP_MEMBERUID, &testattr) && (NULL != testattr)) {
         mapMemberUID = slapi_entry_attr_get_bool(e, POSIX_WINSYNC_MAP_MEMBERUID);
         slapi_log_error(SLAPI_LOG_PLUGIN, POSIX_WINSYNC_PLUGIN_NAME,
-                        "_apply_config: Config paramter %s: %d\n", POSIX_WINSYNC_MAP_MEMBERUID,
+                        "_apply_config: Config parameter %s: %d\n", POSIX_WINSYNC_MAP_MEMBERUID,
                         mapMemberUID);
     }
     /* get create task value */
@@ -256,21 +256,21 @@
         != testattr)) {
         createMemberOfTask = slapi_entry_attr_get_bool(e, POSIX_WINSYNC_CREATE_MEMBEROFTASK);
         slapi_log_error(SLAPI_LOG_PLUGIN, POSIX_WINSYNC_PLUGIN_NAME,
-                        "_apply_config: Config paramter %s: %d\n",
+                        "_apply_config: Config parameter %s: %d\n",
                         POSIX_WINSYNC_CREATE_MEMBEROFTASK, createMemberOfTask);
     }
     /* get lower case UID in memberUID */
     if (!slapi_entry_attr_find(e, POSIX_WINSYNC_LOWER_CASE, &testattr) && (NULL != testattr)) {
         lowercase = slapi_entry_attr_get_bool(e, POSIX_WINSYNC_LOWER_CASE);
         slapi_log_error(SLAPI_LOG_PLUGIN, POSIX_WINSYNC_PLUGIN_NAME,
-                        "_apply_config: Config paramter %s: %d\n", POSIX_WINSYNC_LOWER_CASE,
+                        "_apply_config: Config parameter %s: %d\n", POSIX_WINSYNC_LOWER_CASE,
                         lowercase);
     }
     /* propogate memberuids in nested grouping */
     if (!slapi_entry_attr_find(e, POSIX_WINSYNC_MAP_NESTED_GROUPING, &testattr) && (NULL != testattr)) {
         mapNestedGrouping = slapi_entry_attr_get_bool(e, POSIX_WINSYNC_MAP_NESTED_GROUPING);
         slapi_log_error(SLAPI_LOG_PLUGIN, POSIX_WINSYNC_PLUGIN_NAME,
-                        "_apply_config: Config paramter %s: %d\n", POSIX_WINSYNC_MAP_NESTED_GROUPING,
+                        "_apply_config: Config parameter %s: %d\n", POSIX_WINSYNC_MAP_NESTED_GROUPING,
                         mapNestedGrouping);
     }
     /* if we got here, we have valid values for everything
--- a/ldap/servers/plugins/syntaxes/facsimile.c
+++ b/ldap/servers/plugins/syntaxes/facsimile.c
@@ -241,7 +241,7 @@
 				}
 
 				/* We're guaranteed to have at least one character
-				 * past p.  This is where the fax-paramter should
+				 * past p.  This is where the fax-parameter should
 				 * start. */
 				start = p + 1;
 
@@ -258,9 +258,9 @@
 						}
 
 						/* We're guaranteed to have another character, which
-						 * should be the beginning of the next fax-paramter.
+						 * should be the beginning of the next fax-parameter.
 						 * Adjust the start pointer to point to the beginning
-						 * of this fax-paramter. */
+						 * of this fax-parameter. */
 						start = p + 1;
 					}
 				}
--- a/ldap/servers/slapd/slapi-plugin.h
+++ b/ldap/servers/slapd/slapi-plugin.h
@@ -1635,9 +1635,9 @@
  * \return \c 1 if the entry has any attribute values that violate the syntax rules
  *         imposed by the associated attribute type.  If the \c pb parameter was
  *         passed in, an error message describing the syntax violations will be
- *         set in the #SLAPI_PB_RESULT_TEXT paramter.
+ *         set in the #SLAPI_PB_RESULT_TEXT parameter.
  * \warning The \c pb parameter can be \c NULL.  It is used to store an error
- *         message with details of any syntax violations.  The \c pb paramter
+ *         message with details of any syntax violations.  The \c pb parameter
  *         is also used to check if the #SLAPI_IS_REPLICATED_OPERATION flag is
  *         set.   If that flag is present, no syntax checking is performed.
  */
@@ -1656,7 +1656,7 @@
  *         parameter was passed in, an error message will be set in the
  *         #SLAPI_PB_RESULT_TEXT parameter.
  * \warning The \c pb parameter can be \c NULL.  It is used to store an error
- *         message with details of any syntax violations.  The \c pb paramter
+ *         message with details of any syntax violations.  The \c pb parameter
  *         is also used to check if the #SLAPI_IS_REPLICATED_OPERATION flag is
  *         set.   If that flag is present, no syntax checking is performed.
  */
@@ -1675,9 +1675,9 @@
  * \return \c 1 if the mods are adding any new attribute values that violate the
  *         syntax rules imposed by the associated attribute type.  If the \c pb
  *         parameter was passed in, an error message describing the syntax violations
- *         will be set in the #SLAPI_PB_RESULT_TEXT paramter.
+ *         will be set in the #SLAPI_PB_RESULT_TEXT parameter.
  * \warning The \c pb parameter can be \c NULL.  It is used to store an error
- *         message with details of any syntax violations.  The \c pb paramter
+ *         message with details of any syntax violations.  The \c pb parameter
  *         is also used to check if the #SLAPI_IS_REPLICATED_OPERATION flag is
  *         set.   If that flag is present, no syntax checking is performed.
  */
@@ -2949,7 +2949,7 @@
 int slapi_sdn_scope_test_ext( const Slapi_DN *dn, const Slapi_DN *base, int scope, int flags );
 
 /**
- * Retreives the RDN from a given DN.
+ * Retrieves the RDN from a given DN.
  *
  * This function takes the DN stored in the \c Slapi_DN structure pointed to
  * by \c sdn and fills in it's RDN within the \c Slapi_RDN structure pointed
@@ -4601,7 +4601,7 @@
  *        the value.
  * \param vfrom Pointer to the \c Slapi_Value structure from which to
  *        get the value.
- * \return Pointer to the \c Slapi_Value structure passed as the \c value paramter.
+ * \return Pointer to the \c Slapi_Value structure passed as the \c value parameter.
  * \return \c NULL if the \c value parameter was \c NULL.
  * \warning The \c vfrom parameter must not be \c NULL.
  * \warning If the pointer to the \c Slapi_Value structure is \c NULL,
--- a/ldap/servers/slapd/slapi-private.h
+++ b/ldap/servers/slapd/slapi-private.h
@@ -955,7 +955,7 @@
 
 /* Function:	slapi_uniqueIDNew
    Description: allocates new id
-   Paramters:   none
+   Parameters:  none
    Return:		pointer to the newly allocated id if successful
 				NULL if the system is out of memory
  */
--- a/ldap/servers/plugins/replication/urp.c
+++ b/ldap/servers/plugins/replication/urp.c
@@ -1094,7 +1094,7 @@
 }
 
 /*
- * An URP Naming Collision helper function. Retreives a list of entries
+ * An URP Naming Collision helper function. Retrieves a list of entries
  * that have the given dn excluding the unique id of the entry. Any 
  * entries returned will be entries that have been added with the same
  * dn, but caused a naming conflict when replicated. The URP to fix
--- a/ldap/servers/slapd/passwd_extop.c
+++ b/ldap/servers/slapd/passwd_extop.c
@@ -187,7 +187,7 @@
   
 		slapi_pblock_get(&pb, SLAPI_PLUGIN_INTOP_RESULT, &ret);
 
-		/* Retreive and duplicate the response controls since they will be
+		/* Retrieve and duplicate the response controls since they will be
 		 * destroyed along with the pblock used for the internal operation. */
 		slapi_pblock_get(&pb, SLAPI_RESCONTROLS, &pb_resp_controls);
 		if (pb_resp_controls) {
--- a/lib/libaccess/acltools.cpp
+++ b/lib/libaccess/acltools.cpp
@@ -436,7 +436,7 @@
  *    attr_name		Term Attribute name 
  *    cmp		Comparison operator
  *    attr_pattern	Pattern for comparison
- * Ouput:
+ * Output:
  *    acl_expr		New term added
  * Returns:
  *    0			Success
@@ -518,7 +518,7 @@
  * Input:
  *    errp		The error stack
  *    acl_expr		The expression to negate
- * Ouput
+ * Output
  *    acl_expr		The negated expression
  * Returns:
  *    0			Success

--- a/ldap/servers/slapd/tools/ldclt/ldcltU.c
+++ b/ldap/servers/slapd/tools/ldclt/ldcltU.c
@@ -56,7 +56,7 @@
  * 	     [-S <slave>] [-P<master port>]
  * 	     [-W <waitsec>] [-Z <certfile>]
  * 
  * 	This tool is a ldap client targetted to validate the reliability of
  * 	the product under test under hard use.
  * 
  * 	The valid options are:
@@ -158,7 +158,7 @@
   (void) printf ("	     [-S <slave>] [-P<master port>]\n");
   (void) printf ("	     [-W <waitsec>] [-Z <certfile>]\n");
   (void) printf ("\n");
-  (void) printf ("	This tool is a ldap client targetted to validate the reliability of\n");
+  (void) printf ("	This tool is a ldap client targeted to validate the reliability of\n");
   (void) printf ("	the product under test under hard use.\n");
   (void) printf ("\n");
   (void) printf ("	The valid options are:\n");
@@ -56,7 +56,7 @@
  * 	     [-W <waitsec>] [-Z <certfile>]
  * 
- * 	This tool is a ldap client targetted to validate the reliability of
+ * 	This tool is a ldap client targeted to validate the reliability of
  * 	the product under test under hard use.
  * 